#[repr(transparent)]pub struct SyncUnsafeCell<T>where
T: ?Sized,{
value: UnsafeCell<T>,
}sync_unsafe_cell)Expand description
UnsafeCell, but Sync.
This is just an UnsafeCell, except it implements Sync
if T implements Sync.
UnsafeCell doesn’t implement Sync, to prevent accidental mis-use.
You can use SyncUnsafeCell instead of UnsafeCell to allow it to be
shared between threads, if that’s intentional.
Providing proper synchronization is still the task of the user,
making this type just as unsafe to use.
See UnsafeCell for details.
Fields
value: UnsafeCell<T>sync_unsafe_cell)Implementations
Sourceimpl<T> SyncUnsafeCell<T>
impl<T> SyncUnsafeCell<T>
Sourcepub const fn new(value: T) -> SyncUnsafeCell<T>
🔬This is a nightly-only experimental API. (sync_unsafe_cell)
pub const fn new(value: T) -> SyncUnsafeCell<T>
sync_unsafe_cell)Constructs a new instance of SyncUnsafeCell which will wrap the specified value.
Sourcepub const fn into_inner(self) -> T
🔬This is a nightly-only experimental API. (sync_unsafe_cell)
pub const fn into_inner(self) -> T
sync_unsafe_cell)Unwraps the value, consuming the cell.
Sourceimpl<T> SyncUnsafeCell<T>where
T: ?Sized,
impl<T> SyncUnsafeCell<T>where
T: ?Sized,
Sourcepub const fn get(&self) -> *mut T
🔬This is a nightly-only experimental API. (sync_unsafe_cell)
pub const fn get(&self) -> *mut T
sync_unsafe_cell)Gets a mutable pointer to the wrapped value.
This can be cast to a pointer of any kind.
Ensure that the access is unique (no active references, mutable or not)
when casting to &mut T, and ensure that there are no mutations
or mutable aliases going on when casting to &T
Sourcepub const fn get_mut(&mut self) -> &mut T
🔬This is a nightly-only experimental API. (sync_unsafe_cell)
pub const fn get_mut(&mut self) -> &mut T
sync_unsafe_cell)Returns a mutable reference to the underlying data.
This call borrows the SyncUnsafeCell mutably (at compile-time) which
guarantees that we possess the only reference.
Sourcepub const fn raw_get(this: *const SyncUnsafeCell<T>) -> *mut T
🔬This is a nightly-only experimental API. (sync_unsafe_cell)
pub const fn raw_get(this: *const SyncUnsafeCell<T>) -> *mut T
sync_unsafe_cell)Gets a mutable pointer to the wrapped value.
See UnsafeCell::get for details.